@@ -18,6 +18,10 @@ if(!isGeneric("getInfClip")){
     setGeneric("getInfClip", 
         function(clip, L2deriv, risk, neighbor, ...) standardGeneric("getInfClip"))
 }
+if(!isGeneric("getInfRad")){
+    setGeneric("getInfRad",
+        function(clip, L2deriv, risk, neighbor, ...) standardGeneric("getInfRad"))
+}
 if(!isGeneric("getFixClip")){
     setGeneric("getFixClip", 
         function(clip, Distr, risk, neighbor, ...) standardGeneric("getFixClip"))
@@ -77,18 +81,12 @@ if(!isGeneric("getModifyIC")){
 if(!isGeneric("scaleUpdateIC")){
     setGeneric("scaleUpdateIC", function(neighbor, ...) standardGeneric("scaleUpdateIC"))
 }
-if(!isGeneric("cniperCont")){
-    setGeneric("cniperCont", function(IC1, IC2, L2Fam, neighbor, risk, ...) standardGeneric("cniperCont"))
-}
-if(!isGeneric("cniperPoint")){
-    setGeneric("cniperPoint", function(L2Fam, neighbor, risk, ...) standardGeneric("cniperPoint"))
-}
-if(!isGeneric("cniperPointPlot")){
-    setGeneric("cniperPointPlot", function(L2Fam, neighbor, risk, ...) standardGeneric("cniperPointPlot"))
-}
 if(!isGeneric("eff")){
     setGeneric("eff", function(object) standardGeneric("eff"))
 }
 if(!isGeneric("get.asGRisk.fct")){
     setGeneric("get.asGRisk.fct", function(Risk) standardGeneric("get.asGRisk.fct"))
 }
+if(!isGeneric("getStartIC")){
+    setGeneric("getStartIC", function(model, risk, ...) standardGeneric("getStartIC"))
+}
